@@ -54,33 +54,23 @@ if(is.null(cut)) cut <- .2
    	cat("\ngeneral/max " ,round(gmax,digits),"  max/min =  ",round(maxmin,digits))
     cat("\nmean percent general = ",round(mp2,digits), "   with sd = ", round(sqrt(vp2),digits), "and cv of ",round(sqrt(vp2)/mp2,digits),"\n")
    
-   if(FALSE) {cat("\nCompare three different sets of goodness of fit measures.\nFirst, the omega model:")   #this next section needs to be rethought 
-   
-   if(!is.null(x$stats$dof)) {cat("\nThe degrees of freedom for the omega model are",x$stats$dof," and the fit was ",round(x$stats$objective,digits),"\n")
-   if(!is.null(x$stats$n.obs)&&!is.na(x$stats$n.obs)) {cat("The number of observations was ",x$stats$n.obs, " with Chi Square = ",round(x$stats$STATISTIC,digits), " with prob < ", signif(x$schmid$PVAL,digits),"\n")}
-    }
-    if(!is.null(x$stats$rms)) {cat("\nThe root mean square of the residuals is ", round(x$stats$rms,digits),"\n") }
-     if(!is.null(x$stats$crms)) {cat("The df corrected root mean square of the residuals is ", round(x$stats$crms,digits),"\n") }
-    if(!is.null(x$stats$RMSEA)) {cat("\nRMSEA and the ",x$stats$RMSEA[4]  ,"confidence intervals are ",round(x$stats$RMSEA[1:3],digits+1))  }
-   	if(!is.null(x$stats$BIC)) {cat("\nBIC = ",round(x$stats$BIC,digits))}
-   	cat("\nThen the simple factor model with no higher order factor")
-   	}   #end commented out section
+
    	
    	 if(!is.null(x$schmid$dof)) {cat("\nThe degrees of freedom are",x$schmid$dof," and the fit is ",round(x$schmid$objective,digits),"\n")
     if(!is.null(x$schmid$n.obs)&&!is.na(x$schmid$n.obs)) {cat("The number of observations was ",x$schmid$n.obs, " with Chi Square = ",round(x$schmid$STATISTIC,digits), " with prob < ", signif(x$schmid$PVAL,digits))}
     }
     if(!is.null(x$schmid$rms)) {cat("\nThe root mean square of the residuals is ", round(x$schmid$rms,digits),"\n") }
      if(!is.null(x$schmid$crms)) {cat("The df corrected root mean square of the residuals is ", round(x$schmid$crms,digits)) }
-    if(!is.null(x$schmid$RMSEA)) {cat("\nRMSEA and the ",x$stats$RMSEA[4]  ,"confidence intervals are ",round(x$schmid$RMSEA[1:3],digits+1))  }
+     if(!is.null(x$schmid$RMSEA)) {cat("\nRMSEA index = ",round(x$schmid$RMSEA[1],digits+1), " and the", (1- x$schmid$RMSEA[4])*100,"% confidence intervals are ",round(x$schmid$RMSEA[2:3],digits+1))  }
    	if(!is.null(x$schmid$BIC)) {cat("\nBIC = ",round(x$schmid$BIC,digits))}
    	
-   	cat("\n\nCompare this with the adquacey of just a general factor and no group factors")
+   	cat("\n\nCompare this with the adequacy of just a general factor and no group factors")
    	if(!is.null(x$gstats$dof)) {cat("\nThe degrees of freedom for just the general factor are",x$gstats$dof," and the fit is ",round(x$gstats$objective,digits),"\n")
     if(!is.null(x$gstats$n.obs)&&!is.na(x$gstats$n.obs)) {cat("The number of observations was ",x$gstats$n.obs, " with Chi Square = ",round(x$gstats$STATISTIC,digits), " with prob < ", signif(x$gstats$PVAL,digits))}
     }
     if(!is.null(x$gstats$rms)) {cat("\nThe root mean square of the residuals is ", round(x$gstats$rms,digits),"\n") }
      if(!is.null(x$gstats$crms)) {cat("The df corrected root mean square of the residuals is ", round(x$gstats$crms,digits),"\n") }
-    if(!is.null(x$gstats$RMSEA)) {cat("\nRMSEA and the ",x$gstats$RMSEA[4]  ,"confidence intervals are ",round(x$gstats$RMSEA[1:3],digits+1))  }
+     if(!is.null(x$gstats$RMSEA)) {cat("\nRMSEA index = ",round(x$gstats$RMSEA[1],digits+1), " and the", (1- x$gstats$RMSEA[4])*100,"% confidence intervals are ",round(x$gstats$RMSEA[2:3],digits+1))  }
    	if(!is.null(x$gstats$BIC)) {cat("\nBIC = ",round(x$gstats$BIC,digits),"\n")}
    	
    
